aboutsummaryrefslogtreecommitdiff
path: root/video/dxa_decoder.cpp
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/dxa_decoder.cpp
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/dxa_decoder.cpp')
-rw-r--r--video/dxa_decoder.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/video/dxa_decoder.cpp b/video/dxa_decoder.cpp
index 7e468371d0..bf476def44 100644
--- a/video/dxa_decoder.cpp
+++ b/video/dxa_decoder.cpp
@@ -36,7 +36,7 @@
#include "common/zlib.h"
#endif
-namespace Graphics {
+namespace Video {
DXADecoder::DXADecoder() {
_fileStream = 0;
@@ -477,7 +477,7 @@ void DXADecoder::decode13(int size) {
#endif
}
-const Surface *DXADecoder::decodeNextFrame() {
+const Graphics::Surface *DXADecoder::decodeNextFrame() {
uint32 tag = _fileStream->readUint32BE();
if (tag == MKID_BE('CMAP')) {
_fileStream->read(_palette, 256 * 3);
@@ -559,4 +559,4 @@ const Surface *DXADecoder::decodeNextFrame() {
return _surface;
}
-} // End of namespace Graphics
+} // End of namespace Video